@@ -2,9 +2,9 @@
 
 % Copyright Notice
 %
-%    Copyright (C) 2012, 2013 SUPELEC
+%    Copyright (C) 2012-2014 SUPELEC
 %
-%    Author:  Julien Bect  <julien.bect@supelec.fr>
+%    Author:  Julien Bect  <julien.bect@centralesupelec.fr>
 
 % Copying Permission Statement
 %
@@ -26,11 +26,25 @@
 %    You should  have received a copy  of the GNU  General Public License
 %    along with STK.  If not, see <http://www.gnu.org/licenses/>.
 
-function [x, a, b] = stk_rescale(x, varargin)
+function [x, a, b] = stk_rescale (x, box1, varargin)
 
-[x.data, a, b] = stk_rescale(x.data, varargin{:});
+% Ensure that box1 is an stk_hrect object
+if ~ isa (box1, 'stk_hrect')
+    if isempty (box1)
+        box1 = stk_hrect (size (x, 2));  % Default: [0; 1] ^ DIM
+    else
+        box1 = stk_hrect (box1);
+    end
+end
 
-end % function stk_rescale
+% Rescale using @stk_hrect/stk_rescale
+if isa (x, 'stk_dataframe')
+    [x.data, a, b] = stk_rescale (x.data, box1, varargin{:});
+else
+    [x, a, b] = stk_rescale (x, box1, varargin{:});
+end
+
+end % function
 
 %!test
 %! u = rand(5, 1) * 2;
